%define ALD_Ver		2.0

Name:         zlib

License:      (C) 1995-2004 Jean-loup Gailly and Mark Adler
Summary:      GNU zlib is a general purpose data compression library
Version:      1.2.11
Release:      0

#https://ftp.gnu.org/gnu/

Source: %{name}-%{version}.tar.xz
Source2: %{name}-%{version}-patches.tgz

%define DestDir		/System
# -----------------------------------------------------

%if %{_target_cpu} == %{_build_cpu}
%define _srcrpmdir	%{_topdir}/SRPMS/%{ALD_Ver}
%define _CROSS 0
%define MakeLocCross 0
%else
# rpm --target=armv7hl -ba xxxxx.spec
%define _srcrpmdir	%{_topdir}/SRPMS/tmp
%define _CROSS 1
%define MakeLocCross 1
%define _host %{_arch}-%{_os}%{_gnu}
%endif

#------------------ CROSS DIR --------------------

%define docdir		%{_defaultdocdir}/%{name}

%define auto_local %{_sourcedir}/AUTO_LOCAL-1.sh
%define have_auto_local %(if test -x %{auto_local} ; then echo 1 ; else echo 0 ; fi)

%if %{have_auto_local}
%define __os_install_post %{nil}
%define CrossPath	%(%{auto_local} -GetCrossPath -build_cpu=%{_build_cpu} -target_cpu=%{_target_cpu})
%endif

# ------------------- description ------------------------------------
%description
This package contains the GNU general purpose data compression library
#-------------------------------
%package devel
Summary:      Libraries for the C compiler
Requires:     %{name} = %{version}-%{release}
%description devel
These libraries are needed to compile C code.
-------------------------------
%package devel-static
Summary:      Libraries for the C compiler
Requires:     %{name} = %{version}-%{release}
Requires:     %{name}-devel
%description devel-static
These libraries are needed to compile C code.

# ------------------- setup ------------------------------------------
%Prep
%setup -q -n %{name}-%{version}

tar -xaf %SOURCE2

# https://github.com/madler/zlib/pull/210
patch -p1<patches/zlib-1.2.5-minizip-fixuncrypt.patch
%ifarch s390 s390x
# resolves: #805113
patch -p1<patches/zlib-1.2.11-optimized-s390.patch
%endif
# IBM Z optimalizations
patch -p1<patches/zlib-1.2.11-IBM-Z-hw-accelrated-deflate-s390x.patch
# IBM CRC32 optimalization for POWER archs
patch -p1<patches/zlib-1.2.11-optimized-CRC32-framework.patch
# fixed firefox crash + added test case
patch -p1<patches/zlib-1.2.11-firefox-crash-fix.patch
# fixed covscan issues
patch -p1<patches/zlib-1.2.11-covscan-issues.patch
# fix for IBM Z optimalizations
patch -p1<patches/zlib-1.2.11-IBM-Z-hw-accelrated-deflate-fix.patch
# permit a deflateParams() parameter change
patch -p1<patches/zlib-1.2.11-permit-deflateParams-change.patch
# fixed DFLTCC compression level switching issues
# enabled HW compression for compression levels 1 through 6
patch -p1<patches/zlib-1.2.11-IBM-DFLTCC-compression-level-switching-issues.patch
# fixed inflateSyncPoint() bad return value on z15
patch -p1<patches/zlib-1.2.11-inflateSyncPoint-return-value-fix.patch
# fixed issues found by covscan for rhel-9
# ref: https://github.com/madler/zlib/pull/554
patch -p1<patches/zlib-1.2.11-covscan-issues-rhel9.patch
# Fix for s390x vectorize CRC32
patch -p1<patches/zlib-1.2.11-s390x-vectorize-crc32.patch

patch -p0<patches/pkgconfig.patch

# ------------------- Build ------------------------------------------
%Build
%if %{_CROSS}
export  PATH="%{CrossPath}/bin:$PATH"
export GCC_NoHostPath=d
%endif

%if %{_arch} == "i386"
OPTFLAGS="-O2 -march=i586 -mpreferred-stack-boundary=2 -falign-functions=1 -falign-jumps=1 -falign-loops=1 -fomit-frame-pointer"
%endif
%if %{_arch} == "x86_64"
OPTFLAGS="-O2"
%endif
%if %{_arch} == "arm"
OPTFLAGS="%{optflags} -O2 -munaligned-access"
%endif

OPTFLAGS="$OPTFLAGS -ffunction-sections -fdata-sections -fno-asynchronous-unwind-tables -fno-stack-protector"

export CFLAGS="$OPTFLAGS -std=gnu99"
export LDFLAGS="-Wl,--gc-sections"
export CXXFLAGS="$OPTFLAGS"

./configure \
	--prefix=%{_prefix} \
	--libdir=%{_libdir} \
	--includedir=%{_includedir} \
	&>FConfigure_log.txt

make &>FMake_log.txt

# ------------------- Install ----------------------------------------
%Install
%if %{_CROSS}
export  PATH="%{CrossPath}/bin:$PATH"
export GCC_NoHostPath=d
%endif

rm -rf $RPM_BUILD_ROOT
mkdir -p %{_srcrpmdir}
mkdir -p $RPM_BUILD_ROOT%{docdir}

%makeinstall
cp FAQ README $RPM_BUILD_ROOT%{docdir}/

rm -r $RPM_BUILD_ROOT%{_mandir}

%if %{have_auto_local}
  %{auto_local} -build_cpu=%{_build_cpu} -target_cpu=%{_target_cpu} \
	-target_platform=%{target}-
%endif  # have_auto_local

# ------------------- Clean ------------------------------------------
%Clean
%if %{have_auto_local}
  %{auto_local} -build_cpu=%{_build_cpu} -target_cpu=%{_target_cpu} \
	-ALD_Ver=%{ALD_Ver} -RpmMovePath=%{DestDir} -tar_arg=bzip2
%endif  # have_auto_local

# ------------------- Files ------------------------------------------
%files
%{_libdir}/libz.so.*
%{docdir}

%files devel
%{_includedir}
%{_libdir}/libz.so
%{_libdir}/pkgconfig

%files devel-static
%{_libdir}/libz.a
